==> haskell-fast-logger-2.4.16-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fast-logger
version: 2.4.16
id: fast-logger-2.4.16-1MR7bOm1J8vF9wGaxoSStH
key: fast-logger-2.4.16-1MR7bOm1J8vF9wGaxoSStH
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/logger
synopsis: A fast logging system
description:
    A fast logging system
category: System
abi: 3f3eea91e48aa55f3bc8e8a68bb02a92
exposed: True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Types
hidden-modules: System.Log.FastLogger.IO
                System.Log.FastLogger.FileIO System.Log.FastLogger.IORef
                System.Log.FastLogger.LogStr System.Log.FastLogger.Logger
import-dirs: /usr/lib/ghc-8.6.5/site-local/fast-logger-2.4.16
library-dirs: /usr/lib/ghc-8.6.5/site-local/fast-logger-2.4.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/fast-logger-2.4.16
hs-libraries: HSfast-logger-2.4.16-1MR7bOm1J8vF9wGaxoSStH
depends:
    array-0.5.3.0 auto-update-0.1.6-J50yVDzwbW01Er4rt2tbaI
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    easy-file-0.2.2-49v0RQkxTQF1Wq1oAMulzs filepath-1.4.2.1
    text-1.2.3.1 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unix-time-0.4.7-ISVkQcNmZXrHZK2mPVZsR5
haddock-interfaces: /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html: /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fast-logger-2.4.17-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-fast-logger.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: fast-logger
version: 2.4.17
id: fast-logger-2.4.17-EIkTgShDAYOFSHXqB4KinN
key: fast-logger-2.4.17-EIkTgShDAYOFSHXqB4KinN
license: BSD-3-Clause
maintainer: Kazu Yamamoto <kazu@iij.ad.jp>
author: Kazu Yamamoto <kazu@iij.ad.jp>
homepage: https://github.com/kazu-yamamoto/logger
synopsis: A fast logging system
description:
    A fast logging system
category: System
abi: 7bb65bfbcc595166d2022b9a87d1af1b
exposed: True
exposed-modules:
    System.Log.FastLogger System.Log.FastLogger.Date
    System.Log.FastLogger.File System.Log.FastLogger.Types
hidden-modules: System.Log.FastLogger.Imports
                System.Log.FastLogger.IO System.Log.FastLogger.FileIO
                System.Log.FastLogger.LogStr System.Log.FastLogger.Logger
import-dirs: /usr/lib/ghc-8.6.5/site-local/fast-logger-2.4.17
library-dirs: /usr/lib/ghc-8.6.5/site-local/fast-logger-2.4.17
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/fast-logger-2.4.17
hs-libraries: HSfast-logger-2.4.17-EIkTgShDAYOFSHXqB4KinN
depends:
    array-0.5.3.0 auto-update-0.1.6-9RP5DxOJUcf75OPqVMWXul
    base-4.12.0.0 bytestring-0.10.8.2 directory-1.3.3.0
    easy-file-0.2.2-49v0RQkxTQF1Wq1oAMulzs filepath-1.4.2.1
    text-1.2.3.1 unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unix-time-0.4.7-6BQqpN4x0rZGemgLOEGe7v
haddock-interfaces: /usr/share/doc/haskell-fast-logger/html/fast-logger.haddock
haddock-html: /usr/share/doc/haskell-fast-logger/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
